/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2008 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qmessagebox.h>
#include <qlayout.h>

#include "segatex_alert_audit.h"

//#include <iostream>
//using namespace std;

//default constructor
SegatexAlertAudit::SegatexAlertAudit(QWidget *parent, const char *name): QDialog(parent, name)
{
                setCaption(tr("segatex alert audit"));
                alertLabel = new QLabel(tr("Denied message in audit.log !"), this );
                mainLayout = new QHBoxLayout(this);
                mainLayout->setMargin(11);
                mainLayout->setSpacing(6);
                mainLayout->addWidget(alertLabel);
                resize(300,100);

}
